==> usbserial4a-0.1.9.tar.gz: usbserial4a-0.1.9/usbserial4a/serial4a.py <==
'''Android USB host serial port.

Functions:
get_serial_port
'''

from usb4a import usb
from .ftdiserial4a import FtdiSerial
from .cdcacmserial4a import CdcAcmSerial
from .cp210xserial4a import Cp210xSerial
from .ch34xserial4a import Ch34xSerial
#from .pl2303serial4a import Pl2303Serial

FTDI_VENDOR_ID = 0x0403
SILABS_VENDOR_ID = 0x10C4
QINHENG_VENDOR_ID = 0x1A86
PROLIFIC_VENDOR_ID = 0x067B

FTDI_VID_PID_GROUP = [
    (0x03eb, 0x2109),
    (0x0456, 0xf000),
    (0x0456, 0xf001),
    (0x04d8, 0x000a),
    (0x0584, 0xb020),
    (0x0647, 0x0100),
    (0x06CE, 0x8311),
    (0x06D3, 0x0284),
    (0x0856, 0xac01),
    (0x0856, 0xac02),
    (0x0856, 0xac03),
    (0x0856, 0xac11),
    (0x0856, 0xac12),
    (0x0856, 0xac16),
    (0x0856, 0xac17),
    (0x0856, 0xac18),
    (0x0856, 0xac19),
    (0x0856, 0xac25),
    (0x0856, 0xac26),
    (0x0856, 0xac27),
    (0x0856, 0xac33),
    (0x0856, 0xac34),
    (0x0856, 0xac49),
    (0x0856, 0xac50),
    (0x0856, 0xba02),
    (0x093c, 0x0601),
    (0x093c, 0x0701),
    (0x0acd, 0x0300),
    (0x0b39, 0x0103),
    (0x0b39, 0x0421),
    (0x0c26, 0x0004),
    (0x0c26, 0x0018),
    (0x0c26, 0x0009),
    (0x0c26, 0x000a),
    (0x0c26, 0x000b),
    (0x0c26, 0x000c),
    (0x0c26, 0x000d),
    (0x0c26, 0x0010),
    (0x0c26, 0x0011),
    (0x0c26, 0x0012),
    (0x0c26, 0x0013),
    (0x0c33, 0x0010),
    (0x0c52, 0x2101),
    (0x0c52, 0x2101),
    (0x0c52, 0x2102),
    (0x0c52, 0x2103),
    (0x0c52, 0x2104),
    (0x0c52, 0x9020),
    (0x0c52, 0x2211),
    (0x0c52, 0x2221),
    (0x0c52, 0x2212),
    (0x0c52, 0x2222),
    (0x0c52, 0x2213),
    (0x0c52, 0x2223),
    (0x0c52, 0x2411),
    (0x0c52, 0x2421),
    (0x0c52, 0x2431),
    (0x0c52, 0x2441),
    (0x0c52, 0x2412),
    (0x0c52, 0x2422),
    (0x0c52, 0x2432),
    (0x0c52, 0x2442),
    (0x0c52, 0x2413),
    (0x0c52, 0x2423),
    (0x0c52, 0x2433),
    (0x0c52, 0x2443),
    (0x0c52, 0x2811),
    (0x0c52, 0x2821),
    (0x0c52, 0x2831),
    (0x0c52, 0x2841),
    (0x0c52, 0x2851),
    (0x0c52, 0x2861),
    (0x0c52, 0x2871),
    (0x0c52, 0x2881),
    (0x0c52, 0x2812),
    (0x0c52, 0x2822),
    (0x0c52, 0x2832),
    (0x0c52, 0x2842),
    (0x0c52, 0x2852),
    (0x0c52, 0x2862),
    (0x0c52, 0x2872),
    (0x0c52, 0x2882),
    (0x0c52, 0x2813),
    (0x0c52, 0x2823),
    (0x0c52, 0x2833),
    (0x0c52, 0x2843),
    (0x0c52, 0x2853),
    (0x0c52, 0x2863),
    (0x0c52, 0x2873),
    (0x0c52, 0x2883),
    (0x0c52, 0xa02a),
    (0x0c52, 0xa02b),
    (0x0c52, 0xa02c),
    (0x0c52, 0xa02d),
    (0x0c6c, 0x04b2),
    (0x0c7d, 0x0005),
    (0x0d3a, 0x0300),
    (0x0d46, 0x2020),
    (0x0d46, 0x2021),
    (0x0dcd, 0x0001),
    (0x0f94, 0x0001),
    (0x0f94, 0x0005),
    (0x0fd8, 0x0001),
    (0x103e, 0x03e8),
    (0x104d, 0x3000),
    (0x104d, 0x3002),
    (0x104d, 0x3006),
    (0x1209, 0x1002),
    (0x1209, 0x1006),
    (0x128d, 0x0001),
    (0x1342, 0x0202),
    (0x1457, 0x5118),
    (0x15ba, 0x0003),
    (0x15ba, 0x002b),
    (0x1781, 0x0c30),
    (0x2100, 0x9001),
    (0x2100, 0x9e50),
    (0x2100, 0x9e51),
    (0x2100, 0x9e52),
    (0x2100, 0x9e53),
    (0x2100, 0x9e54),
    (0x2100, 0x9e55),
    (0x2100, 0x9e56),
    (0x2100, 0x9e57),
    (0x2100, 0x9e58),
    (0x2100, 0x9e59),
    (0x2100, 0x9e5a),
    (0x2100, 0x9e5b),
    (0x2100, 0x9e5c),
    (0x2100, 0x9e5d),
    (0x2100, 0x9e5e),
    (0x2100, 0x9e5f),
    (0x2100, 0x9e60),
    (0x2100, 0x9e61),
    (0x2100, 0x9e62),
    (0x2100, 0x9e63),
    (0x2100, 0x9e64),
    (0x2100, 0x9e65),
    (0x2100, 0x9e65),
    (0x2100, 0x9e66),
    (0x2100, 0x9e67),
    (0x2100, 0x9e68),
    (0x2100, 0x9e69),
    (0x2100, 0x9e6a),
    (0x1a72, 0x1000),
    (0x1a72, 0x1001),
    (0x1a72, 0x1002),
    (0x1a72, 0x1005),
    (0x1a72, 0x1007),
    (0x1a72, 0x1008),
    (0x1a72, 0x1009),
    (0x1a72, 0x100d),
    (0x1a72, 0x100e),
    (0x1a72, 0x100f),
    (0x1a72, 0x1011),
    (0x1a72, 0x1012),
    (0x1a72, 0x1013),
    (0x1a72, 0x1014),
    (0x1a72, 0x1015),
    (0x1a72, 0x1016),
    (0x165c, 0x0002),
    (0x1a79, 0x6001),
    (0x1b3d, 0x0100),
    (0x1b3d, 0x0101),
    (0x1b3d, 0x0102),
    (0x1b3d, 0x0103),
    (0x1b3d, 0x0104),
    (0x1b3d, 0x0105),
    (0x1b3d, 0x0106),
    (0x1b3d, 0x0107),
    (0x1b3d, 0x0108),
    (0x1b3d, 0x0109),
    (0x1b3d, 0x010a),
    (0x1b3d, 0x010b),
    (0x1b3d, 0x010c),
    (0x1b3d, 0x010d),
    (0x1b3d, 0x010e),
    (0x1b3d, 0x010f),
    (0x1b3d, 0x0110),
    (0x1b3d, 0x0111),
    (0x1b3d, 0x0112),
    (0x1b3d, 0x0113),
    (0x1b3d, 0x0114),
    (0x1b3d, 0x0115),
    (0x1b3d, 0x0116),
    (0x1b3d, 0x0117),
    (0x1b3d, 0x0118),
    (0x1b3d, 0x0119),
    (0x1b3d, 0x011a),
    (0x1b3d, 0x011b),
    (0x1b3d, 0x011c),
    (0x1b3d, 0x011d),
    (0x1b3d, 0x011e),
    (0x1b3d, 0x011f),
    (0x1b3d, 0x0120),
    (0x1b3d, 0x0121),
    (0x1b3d, 0x0122),
    (0x1b3d, 0x0123),
    (0x1b3d, 0x0124),
    (0x1b3d, 0x0125),
    (0x1b3d, 0x0126),
    (0x1b3d, 0x0127),
    (0x1b3d, 0x0128),
    (0x1b3d, 0x0129),
    (0x1b3d, 0x012a),
    (0x1b3d, 0x012b),
    (0x1b3d, 0x012c),
    (0x1b3d, 0x012e),
    (0x1b3d, 0x012f),
    (0x1b3d, 0x0130),
    (0x1b91, 0x0064),
    (0x1bc9, 0x6001),
    (0x1c0c, 0x0102),
    (0x1cf1, 0x0001),
    (0x1cf1, 0x0041),
    (0x0483, 0x3746),
    (0x0483, 0x3747),
    (0x5050, 0x0100),
    (0x5050, 0x0101),
    (0x5050, 0x0102),
    (0x5050, 0x0103),
    (0x5050, 0x0104),
    (0x5050, 0x0105),
    (0x5050, 0x0106),
    (0x5050, 0x0107),
    (0x5050, 0x0300),
    (0x5050, 0x0301),
    (0x5050, 0x0400),
    (0x5050, 0x0500),
    (0x5050, 0x0700),
    (0x5050, 0x0800),
    (0x5050, 0x0900),
    (0x5050, 0x0a00),
    (0x5050, 0x0b00),
    (0x5050, 0x0c00),
    (0x5050, 0x0d00),
    (0x5050, 0x0e00),
    (0x5050, 0x0f00),
    (0x5050, 0x1000),
    (0x5050, 0x8000),
    (0x5050, 0x8001),
    (0x5050, 0x8002),
    (0x5050, 0x8003),
    (0x5050, 0x8004),
    (0x5050, 0x8005),
    (0x9e88, 0x9e8f),
    (0xdeee, 0x0300),
    (0xdeee, 0x02ff),
    (0xdeee, 0x0302),
    (0xdeee, 0x0303),
    (0x05d1, 0x1001),
    (0x05d1, 0x1002),
    (0x05d1, 0x1003),
    (0x05d1, 0x1004),
    (0x05d1, 0x1011),
    (0x05d1, 0x1013),
    (0x05d1, 0x2001),
    (0x05d1, 0x2002),
    (0x05d1, 0x2003),
    (0x05d1, 0x2011),
    (0x05d1, 0x2012),
    (0x05d1, 0x2021),
    (0x05d1, 0x2022),
    (0x05d1, 0x2023),
    (0x05d1, 0x2024),
    (0x05d1, 0x3011),
    (0x05d1, 0x3012),
    (0x05d1, 0x5001),
    (0x05d1, 0x6001),
    (0x05d1, 0x7001),
    (0x05d1, 0x8001),
    (0x05d1, 0x8002),
    (0x05d1, 0x8003),
    (0x05d1, 0x8004),
    (0x05d1, 0x9001),
    (0x05d1, 0x9002),
    (0x05d1, 0x9003),
    (0x05d1, 0x9004),
    (0x05d1, 0x9005),
    (0x05d1, 0x9006),
    (0x05d1, 0x9007),
    (0x05d1, 0x9008)
]
SILABS_VID_PID_GROUP = [
    (0x045B, 0x0053),
    (0x0471, 0x066A),
    (0x0489, 0xE000),
    (0x0489, 0xE003),
    (0x0745, 0x1000),
    (0x0846, 0x1100),
    (0x08e6, 0x5501),
    (0x08FD, 0x000A),
    (0x0BED, 0x1100),
    (0x0BED, 0x1101),
    (0x0FCF, 0x1003),
    (0x0FCF, 0x1004),
    (0x0FCF, 0x1006),
    (0x0FDE, 0xCA05),
    (0x10A6, 0xAA26),
    (0x10AB, 0x10C5),
    (0x10B5, 0xAC70),
    (0x2405, 0x0003),
    (0x10C5, 0xEA61),
    (0x10CE, 0xEA6A),
    (0x13AD, 0x9999),
    (0x1555, 0x0004),
    (0x166A, 0x0201),
    (0x166A, 0x0301),
    (0x166A, 0x0303),
    (0x166A, 0x0304),
    (0x166A, 0x0305),
    (0x166A, 0x0401),
    (0x166A, 0x0101),
    (0x16D6, 0x0001),
    (0x16DC, 0x0010),
    (0x16DC, 0x0011),
    (0x16DC, 0x0012),
    (0x16DC, 0x0015),
    (0x17A8, 0x0001),
    (0x17A8, 0x0005),
    (0x17F4, 0xAAAA),
    (0x1843, 0x0200),
    (0x18EF, 0xE00F),
    (0x1ADB, 0x0001),
    (0x1BE3, 0x07A6),
    (0x1E29, 0x0102),
    (0x1E29, 0x0501),
    (0x1FB9, 0x0100),
    (0x1FB9, 0x0200),
    (0x1FB9, 0x0201),
    (0x1FB9, 0x0202),
    (0x1FB9, 0x0203),
    (0x1FB9, 0x0300),
    (0x1FB9, 0x0301),
    (0x1FB9, 0x0302),
    (0x1FB9, 0x0303),
    (0x1FB9, 0x0400),
    (0x1FB9, 0x0401),
    (0x1FB9, 0x0402),
    (0x1FB9, 0x0403),
    (0x1FB9, 0x0404),
    (0x1FB9, 0x0600),
    (0x1FB9, 0x0601),
    (0x1FB9, 0x0602),
    (0x1FB9, 0x0700),
    (0x1FB9, 0x0701),
    (0x3195, 0xF190),
    (0x3195, 0xF280),
    (0x3195, 0xF281),
    (0x413C, 0x9500),
    (0x1908, 0x2311)
]
QINHENG_VID_PID_GROUP = [
    (0x4348, 0x5523)
]
PROLIFIC_VID_PID_GROUP = [
    (0x04a5, 0x4027),
    (0x0557, 0x2008),
    (0x0547, 0x2008),
    (0x04bb, 0x0a03),
    (0x04bb, 0x0a0e),
    (0x056e, 0x5003),
    (0x056e, 0x5004),
    (0x0eba, 0x1080),
    (0x0eba, 0x2080),
    (0x0df7, 0x0620),
    (0x0584, 0xb000),
    (0x2478, 0x2008),
    (0x1453, 0x4026),
    (0x0731, 0x0528),
    (0x6189, 0x2068),
    (0x11f7, 0x02df),
    (0x04e8, 0x8001),
    (0x11f5, 0x0001),
    (0x11f5, 0x0003),
    (0x11f5, 0x0004),
    (0x11f5, 0x0005),
    (0x0745, 0x0001),
    (0x078b, 0x1234),
    (0x10b5, 0xac70),
    (0x079b, 0x0027),
    (0x0413, 0x2101),
    (0x0e55, 0x110b),
    (0x0731, 0x2003),
    (0x050d, 0x0257),
    (0x058f, 0x9720),
    (0x11f6, 0x2001),
    (0x07aa, 0x002a),
    (0x05ad, 0x0fba),
    (0x5372, 0x2303),
    (0x03f0, 0x0b39),
    (0x03f0, 0x3139),
    (0x03f0, 0x3239),
    (0x03f0, 0x3524),
    (0x04b8, 0x0521),
    (0x04b8, 0x0522),
    (0x054c, 0x0437),
    (0x11ad, 0x0001),
    (0x0b63, 0x6530),
    (0x0b8c, 0x2303),
    (0x110a, 0x1150),
    (0x0557, 0x2008)
]

def get_serial_port(device_name, *args, **kwargs):
    '''Get a USB serial port from the system.
    
    The parameters are compatible with serial.Serial from pyserial.
    The class of the returned object extends SerialBase from pyserial.
    
    Parameters:
        device_name (str): the name of the USB device.
    
    Returns:
        USB serial port: an object representing the USB serial port.  
    '''
    device = usb.get_usb_device(device_name)
    if device:
        device_vid = device.getVendorId()
        device_pid = device.getProductId()
        if (
            device_vid == FTDI_VENDOR_ID \
            or (device_vid, device_pid) in FTDI_VID_PID_GROUP
        ):
            return FtdiSerial(device_name, *args, **kwargs)
        elif (
            device_vid == SILABS_VENDOR_ID \
            or (device_vid, device_pid) in SILABS_VID_PID_GROUP
        ):
            return Cp210xSerial(device_name, *args, **kwargs)
        elif (
            device_vid == QINHENG_VENDOR_ID \
            or (device_vid, device_pid) in QINHENG_VID_PID_GROUP
        ):
            return Ch34xSerial(device_name, *args, **kwargs)
        elif (
            device_vid == PROLIFIC_VENDOR_ID \
            or (device_vid, device_pid) in PROLIFIC_VID_PID_GROUP
        ):
            #return Pl2303Serial(device_name, *args, **kwargs)
            raise Exception('PL2303 serial driver is not implemented yet!')
        else:
            return CdcAcmSerial(device_name, *args, **kwargs)
    else:
        raise usb.USBError('Device does not exist!')

==> usbserial4a-0.1.10.tar.gz: usbserial4a-0.1.10/usbserial4a/serial4a.py <==
'''Android USB host serial port.

Functions:
get_serial_port
'''

from usb4a import usb
from .vidpid4a import FTDI_VENDOR_ID, SILABS_VENDOR_ID, QINHENG_VENDOR_ID, \
    PROLIFIC_VENDOR_ID, FTDI_VID_PID_GROUP, SILABS_VID_PID_GROUP, \
    QINHENG_VID_PID_GROUP, PROLIFIC_VID_PID_GROUP
from .ftdiserial4a import FtdiSerial
from .cdcacmserial4a import CdcAcmSerial
from .cp210xserial4a import Cp210xSerial
from .ch34xserial4a import Ch34xSerial
from .pl2303serial4a import Pl2303Serial

def get_serial_port(device_name, *args, **kwargs):
    '''Get a USB serial port from the system.
    
    The parameters are compatible with serial.Serial from pyserial.
    The class of the returned object extends SerialBase from pyserial.
    
    Parameters:
        device_name (str): the name of the USB device.
    
    Returns:
        USB serial port: an object representing the USB serial port.  
    '''
    device = usb.get_usb_device(device_name)
    if device:
        device_vid = device.getVendorId()
        device_pid = device.getProductId()
        if (
            device_vid == FTDI_VENDOR_ID \
            or (device_vid, device_pid) in FTDI_VID_PID_GROUP
        ):
            return FtdiSerial(device_name, *args, **kwargs)
        elif (
            device_vid == SILABS_VENDOR_ID \
            or (device_vid, device_pid) in SILABS_VID_PID_GROUP
        ):
            return Cp210xSerial(device_name, *args, **kwargs)
        elif (
            device_vid == QINHENG_VENDOR_ID \
            or (device_vid, device_pid) in QINHENG_VID_PID_GROUP
        ):
            return Ch34xSerial(device_name, *args, **kwargs)
        elif (
            device_vid == PROLIFIC_VENDOR_ID \
            or (device_vid, device_pid) in PROLIFIC_VID_PID_GROUP
        ):
            return Pl2303Serial(device_name, *args, **kwargs)
        else:
            return CdcAcmSerial(device_name, *args, **kwargs)
    else:
        raise usb.USBError('Device does not exist!')
